@@ -1,30 +1,23 @@
 /****************************************************************************
-** Copyright (C) 2019-2020 Klaralvdalens Datakonsult AB, a KDAB Group company, info@kdab.com.
-** All rights reserved.
 **
 ** This file is part of the KD Soap library.
 **
+** SPDX-FileCopyrightText: 2019-2020 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.com>
+**
+** SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDAB-KDSoap OR LicenseRef-KDAB-KDSoap-US
+**
 ** Licensees holding valid commercial KD Soap licenses may use this file in
 ** accordance with the KD Soap Commercial License Agreement provided with
 ** the Software.
 **
+** Contact info@kdab.com if any conditions of this licensing are not clear to you.
 **
-** This file may be distributed and/or modified under the terms of the
-** GNU Lesser General Public License version 2.1 and version 3 as published by the
-** Free Software Foundation and appearing in the file LICENSE.LGPL.txt included.
-**
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-**
-** Contact info@kdab.com if any conditions of this licensing are not
-** clear to you.
-**
-**********************************************************************/
+****************************************************************************/
 
 #include <wsdl.h>
 
-#include <messagehandler.h>
-#include <parsercontext.h>
+#include <common/messagehandler.h>
+#include <common/parsercontext.h>
 
 #include <converter.h>
 #include <creator.h>
@@ -33,7 +26,7 @@
 #include <compiler.h>
 #include "httpserver_p.h"
 
-#include <QtTest>
+#include <QTest>
 
 
 using namespace KDSoapUnitTestHelpers;
